package java.security.cert;

import java.util.HashSet;
import java.util.Iterator;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Set;
import java.util.Map;
import java.util.List;
import java.net.URI;

public abstract class PKIXRevocationChecker extends PKIXCertPathChecker
{
    private URI ocspResponder;
    private X509Certificate ocspResponderCert;
    private List<Extension> ocspExtensions;
    private Map<X509Certificate, byte[]> ocspResponses;
    private Set<PKIXRevocationChecker.Option> options;
    
    protected PKIXRevocationChecker() {
        this.ocspExtensions = Collections.emptyList();
        this.ocspResponses = Collections.emptyMap();
        this.options = Collections.emptySet();
    }
    
    public void setOcspResponder(URI ocspResponder) {
        this.ocspResponder = ocspResponder;
    }
    
    public URI getOcspResponder() {
        return this.ocspResponder;
    }
    
    public void setOcspResponderCert(X509Certificate ocspResponderCert) {
        this.ocspResponderCert = ocspResponderCert;
    }
    
    public X509Certificate getOcspResponderCert() {
        return this.ocspResponderCert;
    }
    
    public void setOcspExtensions(List<Extension> c) {
        this.ocspExtensions = ((c == null) ? Collections.emptyList() : new ArrayList(c));
    }
    
    public List<Extension> getOcspExtensions() {
        return Collections.unmodifiableList(this.ocspExtensions);
    }
    
    public void setOcspResponses(Map<X509Certificate, byte[]> map) {
        if (map == null) {
            this.ocspResponses = Collections.emptyMap();
        }
        else {
            HashMap ocspResponses = new HashMap(map.size());
            for (Map.Entry entry : map.entrySet()) {
                ocspResponses.put(entry.getKey(), ((byte[])entry.getValue()).clone());
            }
            this.ocspResponses = ocspResponses;
        }
    }
    
    public Map<X509Certificate, byte[]> getOcspResponses() {
        HashMap hashMap = new HashMap(this.ocspResponses.size());
        for (Map.Entry entry : this.ocspResponses.entrySet()) {
            hashMap.put(entry.getKey(), ((byte[])entry.getValue()).clone());
        }
        return hashMap;
    }
    
    public void setOptions(Set<PKIXRevocationChecker.Option> c) {
        this.options = ((c == null) ? Collections.emptySet() : new HashSet(c));
    }
    
    public Set<PKIXRevocationChecker.Option> getOptions() {
        return Collections.unmodifiableSet(this.options);
    }
    
    public abstract List<CertPathValidatorException> getSoftFailExceptions();
    
    @Override
    public PKIXRevocationChecker clone() {
        PKIXRevocationChecker pkixRevocationChecker = (PKIXRevocationChecker)super.clone();
        pkixRevocationChecker.ocspExtensions = new ArrayList(this.ocspExtensions);
        pkixRevocationChecker.ocspResponses = new HashMap(this.ocspResponses);
        for (Map.Entry entry : pkixRevocationChecker.ocspResponses.entrySet()) {
            entry.setValue(((byte[])entry.getValue()).clone());
        }
        pkixRevocationChecker.options = new HashSet(this.options);
        return pkixRevocationChecker;
    }
    
    public enum Option
    {
        ONLY_END_ENTITY, 
        PREFER_CRLS, 
        NO_FALLBACK, 
        SOFT_FAIL;
    }
}
